==> eiffelstudio-18.01.10.1424.tar: F_code/C8/gb399.c <==
/*
 * Code for class GB_EV_CONTAINER_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb399.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_CONTAINER_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F663_6529_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 662, Current, 0, 0, 6847);
	RTGC;
	RTOSP (6529);
#define Result RTOSR(6529)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("new_item_actions",16,2002975091);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	F431_5905(RTCW(Result));
	RTOSE (6529);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6529 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6529,F663_6529_body,(Current));
}

/* {GB_EV_CONTAINER_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F663_6530_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 662, Current, 0, 0, 6848);
	RTGC;
	RTOSP (6530);
#define Result RTOSR(6530)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_NEW_ITEM_ACTION_SEQUENCE",27,863551813);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6530);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6530 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6530,F663_6530_body,(Current));
}

/* {GB_EV_CONTAINER_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F663_6531_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 662, Current, 0, 0, 6849);
	RTGC;
	RTOSP (6531);
#define Result RTOSR(6531)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when a new item is added.",52,411844654);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6531);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6531 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6531,F663_6531_body,(Current));
}

void EIF_Minit399 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C8/gb399.c <==
/*
 * Code for class GB_EV_TEXT_FIELD_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb399.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_TEXT_FIELD_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F663_6529_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 662, Current, 0, 0, 6847);
	RTGC;
	RTOSP (6529);
#define Result RTOSR(6529)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("return_actions",14,2009533299);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	F431_5905(RTCW(Result));
	RTOSE (6529);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6529 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6529,F663_6529_body,(Current));
}

/* {GB_EV_TEXT_FIELD_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F663_6530_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 662, Current, 0, 0, 6848);
	RTGC;
	RTOSP (6530);
#define Result RTOSR(6530)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6530);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6530 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6530,F663_6530_body,(Current));
}

/* {GB_EV_TEXT_FIELD_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F663_6531_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 662, Current, 0, 0, 6849);
	RTGC;
	RTOSP (6531);
#define Result RTOSR(6531)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when return key is pressed.",54,1585697838);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6531);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F663_6531 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6531,F663_6531_body,(Current));
}

void EIF_Minit399 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
